IntercomError class

Constructors

IntercomError(int errorCode, String errorMessage)
Class for the Intercom error data.

Properties

errorCode → int
error code
final
errorMessage → String
error message
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited