IntercomStatusCallback class

Constructors

IntercomStatusCallback({dynamic onSuccess()?, dynamic onFailure(IntercomError error)?})
Class for intercom status to check if the operation is success or failure. If the operation failed then onFailure callback will be executed with IntercomError details.

Properties

hashCode → int
The hash code for this object.
no setterinherited
onFailure → dynamic Function(IntercomError error)?
Callback when intercom operation is failed. It will contain the error information.
final
onSuccess → dynamic Function()?
Callback when intercom operation is success.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited